diff graal/com.oracle.truffle.api/src/com/oracle/truffle/api/frame/Frame.java @ 12643:856a9864ed93

Frame: add is<Type> methods.
author Andreas Woess <andreas.woess@jku.at>
date Wed, 30 Oct 2013 20:01:50 +0100
parents 139b84d713bc
children 64dcb92ee75a
line wrap: on
line diff
--- a/graal/com.oracle.truffle.api/src/com/oracle/truffle/api/frame/Frame.java	Wed Oct 30 17:31:13 2013 +0100
+++ b/graal/com.oracle.truffle.api/src/com/oracle/truffle/api/frame/Frame.java	Wed Oct 30 20:01:50 2013 +0100
@@ -191,11 +191,37 @@
     MaterializedFrame materialize();
 
     /**
-     * To check whether the given {@link FrameSlot} has been initialized or not. An initialized slot
-     * has previously been read or modified.
-     * 
-     * @param slot the slot
-     * @return true if the slot is uninitialized.
+     * Check whether the given {@link FrameSlot} is of type object.
+     */
+    boolean isObject(FrameSlot slot);
+
+    /**
+     * Check whether the given {@link FrameSlot} is of type byte.
+     */
+    boolean isByte(FrameSlot slot);
+
+    /**
+     * Check whether the given {@link FrameSlot} is of type boolean.
+     */
+    boolean isBoolean(FrameSlot slot);
+
+    /**
+     * Check whether the given {@link FrameSlot} is of type int.
      */
-    boolean isInitialized(FrameSlot slot);
+    boolean isInt(FrameSlot slot);
+
+    /**
+     * Check whether the given {@link FrameSlot} is of type long.
+     */
+    boolean isLong(FrameSlot slot);
+
+    /**
+     * Check whether the given {@link FrameSlot} is of type float.
+     */
+    boolean isFloat(FrameSlot slot);
+
+    /**
+     * Check whether the given {@link FrameSlot} is of type double.
+     */
+    boolean isDouble(FrameSlot slot);
 }